@@ -1,5 +1,5 @@
 package Mojo::Weixin;
-our $VERSION = '1.0.5';
+our $VERSION = '1.0.6';
 use Mojo::Weixin::Base 'Mojo::EventEmitter';
 use Mojo::IOLoop;
 use Mojo::Weixin::Log;
@@ -14,7 +14,7 @@ has log_path            => undef;
 has log_encoding        => undef;      #utf8|gbk|...
 
 has tmpdir              => sub {File::Spec->tmpdir();};
-has pic_dir             => sub {$_[0]->tmpdir};
+has media_dir           => sub {$_[0]->tmpdir};
 has cookie_dir          => sub {return $_[0]->tmpdir;};
 has qrcode_path         => sub {File::Spec->catfile($_[0]->tmpdir,join('','mojo_weixin_qrcode','.png'))};
 has ioloop              => sub {Mojo::IOLoop->singleton};
@@ -89,11 +89,42 @@ sub gen_deviceid {
 }
 sub on {
     my $self = shift;
+    my @return;
     while(@_){
         my($event,$callback) = (shift,shift);
-        $self->SUPER::on($event,$callback);
+        push @return,$self->SUPER::on($event,$callback);
     }
-    return $self;
+    return wantarray?@return:$return[0];
+}
+
+sub wait_once {
+    my $self = shift;
+    my($timeout,$timeout_callback,$event,$event_callback)=@_;
+    my ($timer_id, $subscribe_id);
+    $timer_id = $self->timer($timeout,sub{
+        $self->unsubscribe($event,$subscribe_id);
+        $timeout_callback->(@_) if ref $timeout_callback eq "CODE";
+    });
+    $subscribe_id = $self->once($event=>sub{
+        $self->ioloop->remove($timer_id);
+        $event_callback->(@_) if ref $event_callback eq "CODE";
+    });
+    $self;
+}
+
+sub wait {
+    my $self = shift;
+    my($timeout,$timeout_callback,$event,$event_callback)=@_;
+    my ($timer_id, $subscribe_id);
+    $timer_id = $self->timer($timeout,sub{
+        $self->unsubscribe($event,$subscribe_id);
+        $timeout_callback->(@_) if ref $timeout_callback eq "CODE";;
+    });
+    $subscribe_id = $self->on($event=>sub{
+        my $ret = ref $event_callback eq "CODE"?$event_callback->(@_):0;
+        if($ret){ $self->ioloop->remove($timer_id);$self->unsubscribe($event,$subscribe_id); }
+    });
+    $self;
 }
 sub new {
     my $class = shift;
