@@ -53,7 +53,13 @@ sub _http_request{
             if($self->ua_debug){
                 $self->print("-- Non-blocking request (@{[$tx->req->url->to_abs]})\n");
                 $self->print("-- Client >>> Server (@{[$tx->req->url->to_abs]})\n@{[$tx->req->to_string]}\n");
-                $self->print("-- Server >>> Client (@{[$tx->req->url->to_abs]})\n@{[$tx->res->to_string]}\n");
+                my $content_type = eval {$tx->res->headers->content_type};
+                if(defined $content_type and $content_type =~m#^image/|^application/octet-stream#){
+                    $self->print("-- Server >>> Client (@{[$tx->req->url->to_abs]})\n@{[$tx->res->build_start_line . $tx->res->build_headers]}\n");
+                }
+                else{
+                    $self->print("-- Server >>> Client (@{[$tx->req->url->to_abs]})\n@{[$tx->res->to_string]}\n");
+                }
             }
             $self->save_cookie();
             if(defined $tx and $tx->success){
@@ -77,7 +83,13 @@ sub _http_request{
             if($self->ua_debug){
                 $self->print("-- Blocking request (@{[$tx->req->url->to_abs]})\n");
                 $self->print("-- Client >>> Server (@{[$tx->req->url->to_abs]})\n@{[$tx->req->to_string]}\n");
-                $self->print("-- Server >>> Client (@{[$tx->req->url->to_abs]})\n@{[$tx->res->to_string]}\n");
+                my $content_type = eval {$tx->res->headers->content_type};
+                if(defined $content_type and $content_type =~m#^image/|^application/octet-stream#){
+                    $self->print("-- Server >>> Client (@{[$tx->req->url->to_abs]})\n@{[$tx->res->build_start_line . $tx->res->build_headers]}\n");
+                }
+                else{
+                    $self->print("-- Server >>> Client (@{[$tx->req->url->to_abs]})\n@{[$tx->res->to_string]}\n");
+                }
             }
             $self->save_cookie();
             if(defined $tx and $tx->success){
